@@ -10,7 +10,8 @@ import argparse
 import sys
 
 from ropgadget.updateAlert import UpdateAlert
-from ropgadget.version     import *
+from ropgadget.version import *
+
 
 class Args(object):
     def __init__(self, arguments=None):
@@ -19,9 +20,8 @@ class Args(object):
 
         # If no custom arguments are provided, use the program arguments
         if not arguments:
-          arguments = sys.argv[1:]
-          custom_arguments_provided = False
-
+            arguments = sys.argv[1:]
+            custom_arguments_provided = False
 
         self.__parse(arguments, custom_arguments_provided)
 
@@ -85,7 +85,7 @@ architectures supported:
         parser.add_argument("--re",                 type=str, metavar="<re>",         help="Regular expression")
         parser.add_argument("--offset",             type=str, metavar="<hexaddr>",    help="Specify an offset for gadget addresses")
         parser.add_argument("--ropchain",           action="store_true",              help="Enable the ROP chain generation")
-        parser.add_argument("--thumb"  ,            action="store_true",              help="Use the thumb mode for the search engine (ARM only)")
+        parser.add_argument("--thumb",              action="store_true",              help="Use the thumb mode for the search engine (ARM only)")
         parser.add_argument("--console",            action="store_true",              help="Use an interactive console for search engine")
         parser.add_argument("--norop",              action="store_true",              help="Disable ROP search engine")
         parser.add_argument("--nojop",              action="store_true",              help="Disable JOP search engine")
@@ -96,16 +96,16 @@ architectures supported:
         parser.add_argument("--noinstr",            action="store_true",              help="Disable the gadget instructions console printing")
         parser.add_argument("--dump",               action="store_true",              help="Outputs the gadget bytes")
         parser.add_argument("--silent",             action="store_true",              help="Disables printing of gadgets during analysis")
+        parser.add_argument("--align",              type=int,                         help="Align gadgets addresses (in bytes)")
+        parser.add_argument("--mipsrop",            type=str, metavar="<rtype>",      help="MIPS useful gadgets finder stackfinder|system|tails|lia0|registers")
 
         self.__args = parser.parse_args(arguments)
 
         if self.__args.noinstr and self.__args.only:
-            print("[Error] --noinstr and --only=<key> can't be used together")
-            sys.exit(-1)
+            raise ValueError("[Error] --noinstr and --only=<key> can't be used together")
 
         if self.__args.noinstr and self.__args.re:
-            print("[Error] --noinstr and --re=<re> can't be used together")
-            sys.exit(-1)
+            raise ValueError("[Error] --noinstr and --re=<re> can't be used together")
 
         if self.__args.version:
             self.__printVersion()
@@ -116,29 +116,25 @@ architectures supported:
             sys.exit(0)
 
         elif self.__args.depth < 2:
-            print("[Error] The depth must be >= 2")
-            sys.exit(-1)
+            raise ValueError("[Error] The depth must be >= 2")
 
         elif not custom_arguments_provided and not self.__args.binary and not self.__args.console:
-            print("[Error] Need a binary filename (--binary/--console or --help)")
-            sys.exit(-1)
+            raise ValueError("[Error] Need a binary filename (--binary/--console or --help)")
 
         elif self.__args.range:
             try:
                 rangeS = int(self.__args.range.split('-')[0], 16)
                 rangeE = int(self.__args.range.split('-')[1], 16)
             except:
-                print("[Error] A range must be set in hexadecimal. Ex: 0x08041000-0x08042000")
-                sys.exit(-1)
+                raise ValueError("[Error] A range must be set in hexadecimal. Ex: 0x08041000-0x08042000")
             if rangeS > rangeE:
-                print("[Error] The start value must be greater than end value")
-                sys.exit(-1)
+                raise ValueError("[Error] The start value must be greater than end value")
 
     def __printVersion(self):
-        print("Version:        %s" %(PYROPGADGET_VERSION))
-        print("Author:         Jonathan Salwan" )
-        print("Author page:    https://twitter.com/JonathanSalwan" )
-        print("Project page:   http://shell-storm.org/project/ROPgadget/" )
+        print("Version:        %s" % (PYROPGADGET_VERSION))
+        print("Author:         Jonathan Salwan")
+        print("Author page:    https://twitter.com/JonathanSalwan")
+        print("Project page:   http://shell-storm.org/project/ROPgadget/")
 
     def getArgs(self):
         return self.__args
